AccountExecFns

Trait AccountExecFns 

pub trait AccountExecFns<Chain, CwOrchExecuteMsgType, Authenticator = Empty>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>
where Chain: TxHandler, Authenticator: Debug + Serialize + DeserializeOwned, ExecuteMsg<Authenticator>: Into<CwOrchExecuteMsgType>,
{
Show 17 methods // Provided methods fn execute_msgs( &self, msgs: Vec<CosmosMsg>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn execute_with_data( &self, msg: CosmosMsg, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn execute_on_module( &self, exec_msg: Binary, funds: Vec<Coin>, module_id: impl Into<String>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn admin_execute( &self, addr: impl Into<String>, msg: Binary, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn admin_execute_on_module( &self, module_id: impl Into<String>, msg: Binary, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn ica_action( &self, action_query_msg: Binary, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn update_internal_config( &self, arg0: InternalConfigAction, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn install_modules( &self, modules: Vec<ModuleInstallConfig>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn uninstall_module( &self, module_id: impl Into<String>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn upgrade( &self, modules: Vec<(ModuleInfo, Option<Binary>)>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn create_sub_account( &self, install_modules: Vec<ModuleInstallConfig>, account_id: Option<u32>, description: Option<String>, link: Option<String>, name: Option<String>, namespace: Option<String>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn update_info( &self, description: Option<String>, link: Option<String>, name: Option<String>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn update_status( &self, is_suspended: Option<bool>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn update_sub_account( &self, arg0: UpdateSubAccountAction, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn update_ownership( &self, arg0: GovAction, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn add_auth_method( &self, add_authenticator: Authenticator, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... } fn remove_auth_method( &self, id: u8, ) -> Result<<Chain as TxHandler>::Response, CwEnvError> { ... }
}
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn execute_msgs( &self, msgs: Vec<CosmosMsg>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Execute variant

fn execute_with_data( &self, msg: CosmosMsg, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ExecuteWithData variant

fn execute_on_module( &self, exec_msg: Binary, funds: Vec<Coin>, module_id: impl Into<String>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ExecuteOnModule variant

fn admin_execute( &self, addr: impl Into<String>, msg: Binary, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::AdminExecute variant

fn admin_execute_on_module( &self, module_id: impl Into<String>, msg: Binary, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::AdminExecuteOnModule variant

fn ica_action( &self, action_query_msg: Binary, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::IcaAction variant

fn update_internal_config( &self, arg0: InternalConfigAction, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateInternalConfig variant

fn install_modules( &self, modules: Vec<ModuleInstallConfig>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::InstallModules variant

fn uninstall_module( &self, module_id: impl Into<String>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UninstallModule variant

fn upgrade( &self, modules: Vec<(ModuleInfo, Option<Binary>)>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Upgrade variant

fn create_sub_account( &self, install_modules: Vec<ModuleInstallConfig>, account_id: Option<u32>, description: Option<String>, link: Option<String>, name: Option<String>, namespace: Option<String>, coins: &[Coin], ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::CreateSubAccount variant

fn update_info( &self, description: Option<String>, link: Option<String>, name: Option<String>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateInfo variant

fn update_status( &self, is_suspended: Option<bool>, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateStatus variant

fn update_sub_account( &self, arg0: UpdateSubAccountAction, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateSubAccount variant

fn update_ownership( &self, arg0: GovAction, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateOwnership variant

fn add_auth_method( &self, add_authenticator: Authenticator, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::AddAuthMethod variant

fn remove_auth_method( &self, id: u8, ) -> Result<<Chain as TxHandler>::Response, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RemoveAuthMethod variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain, CwOrchExecuteMsgType, Authenticator, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType, Authenticator> for SupportedContract
where Chain: TxHandler, Authenticator: Debug + Serialize + DeserializeOwned, ExecuteMsg<Authenticator>: Into<CwOrchExecuteMsgType>, SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,

Available on non-WebAssembly only.